/******************************************************************************
* To the extent possible under law, Sebastian Roith
* <https://www.roith-unterrichtet.de> has waived all copyright and related or
* neighboring rights to this script. This work is published from Germany.
******************************************************************************/

/**
* Klasse, die ein nummerisches Attribut ein- und auslesen kann
*/
function AttributeString(
    attributeName,      // Attributname
    required            // Optional: Muss dieses Attribut angegeben sein?
) {
    Object.defineProperty(this, 'attributeName', { 'value': attributeName, 'enumerable': true });
    if (required)
        this.required = true;
}

// Attributname
AttributeString.prototype.attributeName = 'text';

// Muss dieses Attribut angegeben sein?
AttributeString.prototype.required = false;

// Muss der String zwingend in doppelten Anführungszeichen eingeschlossen sein?
AttributeString.prototype.needValidString = false;

// Standardwert
AttributeString.prototype.defaultValue = "";

/**
* Zum zugehörigen Attributwert in obj die Bezeichnung ermitteln
* @return String        Bezeichnung des Werts (false, wenn kein Attributwert angegeben)
*/
AttributeString.prototype.nameValue = function(
    obj     // Objekt mit den Attributwerten
) {
    var value = obj[this.attributeName];
    if (value === undefined)
        return false;
    return '"' + value.replace('\\', '\\\\').replace('"', '\\"') + '"';
}

/**
* Den zur Angabe strKey passenden Attributwert im Objekt obj eintragen
* @return String        Im Fehlerfall Fehlermeldung
*/
AttributeString.prototype.readValue = function(
    strKey,     // Von Benutzer eingegebener Wert, der tatsächlichen Attributwert beschreibt
    obj         // Objekt für tatsächliche Attributwerte
) {
    var noValue = (strKey === undefined) || (strKey === false) || !strKey.length;
    if (noValue && this.required)
        return 'Wert ' + (this.attributeName ? ('des Attributs „' + this.attributeName + '“ ') : '') + 'fehlt';
    if (noValue) {
        obj[this.attributeName] = this.defaultValue;
        return;
    }
    var boolValid = (strKey.length > 1) && (strKey.charAt(0) == '"') && (strKey.charAt(strKey.length - 1) == '"');
    value = strKey;
    if (boolValid) {
        var parts = strKey.substr(1, strKey.length - 2).split('\\\\');
        var lastPart = parts[parts.length - 1];
        boolValid = (lastPart.charAt(lastPart.length - 1) != '\\');
        if (boolValid)
            value = parts.map(function(s) { return s.replace(/\\/g, ''); }).join('\\');
    }
    if (!boolValid && this.needValidString)
        return 'Wert ' + (this.attributeName ? ('des Attributs „' + this.attributeName + '“') : '') + ' ist ungültig, weil er nicht in doppelte Anführungszeichen eingeschlossen ist';
    obj[this.attributeName] = value;
    return;
}
