/******************************************************************************
* To the extent possible under law, Sebastian Roith
* <https://www.roith-unterrichtet.de> has waived all copyright and related or
* neighboring rights to this script. This work is published from Germany.
******************************************************************************/

/**
* Daten von formatierbaren Zeichen
*/
function CharsDataBuilder() {
    this._attributes = [
        new AttributeString('text'),
        new AttributeSet('schriftart', [ 'mitSerifen', 'ohneSerifen', 'handschrift', 'nichtproportional', 'aussergewoehnlich', 'symbole' ]),
        new AttributeNumber('groesse', 1, 100, 1),
        new AttributeBoolean('fett'),
        new AttributeBoolean('kursiv'),
        new AttributeBoolean('unterstrichen'),
        new AttributeColor('farbe', true),
        new AttributeColor('hintergrund', true),
        new AttributeBoolean('kapitaelchen')
    ];
    this._attributes[2].defaultValue = 12;
}

// Alle Attribute
CharsDataBuilder.prototype._attributes = [];

/**
* Alle Attributnamen ermitteln
* @return Array     Attributnamen als Strings
*/
CharsDataBuilder.prototype.getAttributeNames = function() {
    return this._attributes.map(function(item) { return item.attributeName; });
}

/**
* Eingegebene Attributwerte in tatsächliche Attributwerte umwandeln
* @return Object    Objekt mit Attributen message (Fehlermeldung, falls vorhanden) und object (Objekt mit tatsächlichen Attributwerten)
*/
CharsDataBuilder.prototype.createFromAtts = function(
    atts        // Eingegebene Attributwerte
) {
    var obj = {};
    var s;
    for (var n = 0; n < this._attributes.length; ++n) {
        if (s = this._attributes[n].readValue(atts[this._attributes[n].attributeName], obj))
            return { message: s, object: obj };
    }
    return { message: '', object: obj };
}
