/******************************************************************************
* To the extent possible under law, Sebastian Roith
* <https://www.roith-unterrichtet.de> has waived all copyright and related or
* neighboring rights to this script. This work is published from Germany.
******************************************************************************/

/**
* Klasse, um aus einem Objekt mit tatsächlichen Attributwerten einen entsprechenden DOM-Knoten zu machen
*/
function CharsNodeBuilder() {
}

/**
* Erstellt einen DOM-Knoten anhand von Attributwerten
* @return HTMLElement   Erstellter DOM-Knoten
*/
CharsNodeBuilder.prototype.create = function(
    atts        // Objekt mit den tatsächlichen Attributwerten
) {
    var span = ScoTools.createHtml('span', undefined, null, atts.text);
    span.className = 'fontFamily_' + ((atts.schriftart === undefined) ? 'mitSerifen' : atts.schriftart);
    if (atts.groesse)
        span.style.fontSize = atts.groesse + 'pt';
    if (atts.fett)
        span.style.fontWeight = 'bold';
    if (atts.kursiv)
        span.style.fontStyle = 'italic';
    if (atts.unterstrichen)
        span.style.textDecoration = 'underline';
    if (atts.kapitaelchen)
        span.style.fontVariant = 'small-caps';
    if (atts.farbe)
        span.style.color = atts.farbe;
    if (atts.hintergrund)
        span.style.backgroundColor = atts.hintergrund;
    return span;
}

/**
* Erstellt einen DOM-Knoten anhand von Attributwerten und ersetzt nodeOld durch den neu erstellten Knoten bzw. fügt ihn am Ende von parentNode ein
* @return SVGElement    Erstellter DOM-Knoten
*/
CharsNodeBuilder.prototype.change = function(
    atts,       // Objekt mit den tatsächlichen Attributwerten
    nodeOld,    // Zu ersetzender DOM-Knoten
    parentNode  // Übergeordneter DOM-Knoten
) {
    var node = this.create(atts);
    if (nodeOld && nodeOld.parentNode)
        nodeOld.parentNode.replaceChild(node, nodeOld);
    else
        parentNode.appendChild(node);
    return node;
}
